@@ -29,7 +29,7 @@ my $factor        = $F->{'BITS'} / 16;
 
 $F->normal_mode();
 $F->cls('OFF');
-
+if (0) {
 print_it($F,'Plotting Test');
 foreach my $p (1..2000) {
     $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
@@ -373,17 +373,26 @@ foreach my $re (1..(5 * $factor)) {
 }
 
 sleep $wait;
-
+}
 print_it($F,'Image load');
 
-$F->blit_write($F->load_image(
-    {
-        'x' => 0,
-        'y' => 0,
-        'file' => 'RWBY_Faces.png',
+foreach my $file (qw(RWBY_Faces.png examples/RWBY_Faces.png)) {
+    if (-e $file) {
+        my $image = $F->load_image(
+            {
+                'x' => 0,
+                  'y' => 0,
+                  'file' => $file,
+            }
+        );
+        
+        foreach my $i (1..(50 * $factor)) {
+            $image->{'x'} = rand($XX - $image->{'width'});
+            $image->{'y'} = rand($YY - $image->{'height'});
+            $F->blit_write($image);
+        }
     }
-));
-
+}
 sleep $wait;
 
 $F->cls('ON');
